@@ -311,7 +311,7 @@ def _file_exists(context, path):
     def key_exists():
         key = _key(context, path)
         response = _head_object(context, context.s3_bucket, key)
-
+        print('key',response)
         return response
 
     return False if _is_root(path) else (yield key_exists())
@@ -450,6 +450,7 @@ def _save_directory(context, chunk, content, path):
 
 @gen.coroutine
 def _save_any(context, chunk, content_bytes, path, type, mimetype):
+
     response = \
         (yield _save_bytes(context, content_bytes, path, type, mimetype)) if chunk is None else \
         (yield _save_chunk(context, chunk, content_bytes, path, type, mimetype))
@@ -819,6 +820,7 @@ def _head_object(context, bucket, key):
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     response = s3_client.head_object(Bucket=bucket, Key=key)
+    print('head',response)
     if 'ContentLength' in response and response['ContentLength'] >= 0:
         return True
     else:
